.. image:: https://readthedocs.org/projects/wipy-tools/badge/?version=latest
    :target: http://wipy-tools.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status


WIPY Tools
==========

This python package contains tools for working with the `wipy <http://www.pycom.io/product/wipy-expansion-board/>`_
microcontroller with Micropython.


For details on using the command line utility or configuring the PyCharm IDE for WiPy project development see the
documentation.

